@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 require 'sprockets/digest_utils'
-require 'sprockets/source_map_utils' if Gem::Version.new(::Sprockets::VERSION) >= Gem::Version.new('4.x')
+require 'sprockets/source_map_utils' if Gem::Version.new(Sprockets::VERSION) >= Gem::Version.new('4.x')
 
 class Terser
   # A wrapper for Sprockets
@@ -10,7 +10,7 @@ class Terser
 
     def initialize(options = {})
       options[:comments] ||= :none
-      @options = options
+      @options = options.merge(Rails.application.config.assets.terser.to_h)
       @cache_key = -"Terser:#{::Terser::VERSION}:#{VERSION}:#{::Sprockets::DigestUtils.digest(options)}"
       @terser = ::Terser.new(@options)
     end
